@@ -43,8 +43,10 @@ def make_wide(formatter, w=120, h=36):
         warnings.warn("argparse help formatter failed, falling back.")
         return formatter
 
-def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_base=None, 
-               reset=None, args=None):
+def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, 
+                savedir_base=None, 
+               reset=None, args=None, use_threads=False,
+               exp_id=None):
     if args is None:
         args = get_args()
 
@@ -52,13 +54,14 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_ba
     # =======
     savedir_base = savedir_base or args.savedir_base
     reset = reset or args.reset
+    exp_id = exp_id or args.exp_id
     assert savedir_base is not None
 
     # Collect experiments
     # ===================
-    if args.exp_id is not None:
+    if exp_id is not None:
         # select one experiment
-        savedir = os.path.join(savedir_base, args.exp_id)
+        savedir = os.path.join(savedir_base, exp_id)
         exp_dict = hu.load_json(os.path.join(savedir, "exp_dict.json"))
 
         exp_list = [exp_dict]
@@ -70,7 +73,7 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_ba
             exp_list += exp_groups[exp_group_name]
 
     # save results folder
-    if args.exp_id is None:
+    if exp_id is None:
         results_fname = args.visualize_notebook
         if len(results_fname):
             if '.ipynb' not in results_fname:
@@ -78,6 +81,7 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_ba
             create_jupyter_file(fname=results_fname,
                                 savedir_base=savedir_base)
 
+    hu.check_duplicates(exp_list)
     print('\nRunning %d experiments' % len(exp_list))
 
     # Run experiments
@@ -94,6 +98,7 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_ba
         # launch jobs
         from haven import haven_jobs as hjb
         assert job_config is not None
+        assert 'account_id' in job_config
         jm = hjb.JobManager(exp_list=exp_list,
                             savedir_base=savedir_base,
                             workdir=os.getcwd(),
@@ -104,7 +109,7 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, savedir_ba
                    (savedir_base, args.datadir))
 
         print(command)
-        jm.launch_menu(command=command)
+        jm.launch_menu(command=command, in_parallel=use_threads)
 
 
 def create_jupyter_file(fname, savedir_base):
@@ -170,8 +175,8 @@ def create_experiment(exp_dict, savedir_base, reset, copy_code=False, return_exp
 
     #-- exp_dict
     exp_dict_json_fname = os.path.join(savedir, "exp_dict.json")
-    if not os.path.exists(exp_dict_json_fname):
-        hu.save_json(exp_dict_json_fname, exp_dict)
+    # if not os.path.exists(exp_dict_json_fname):
+    hu.save_json(exp_dict_json_fname, exp_dict)
 
     #-- images
     os.makedirs(os.path.join(savedir, 'images'), exist_ok=True)
